netapp_ontap.models.nvme_subsystem_replication_error API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nvme_subsystem_replication_error`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NvmeSubsystemReplicationErrorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NvmeSubsystemReplicationError object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `subsystem: ReplicationErrorSubsystem GET POST PATCH`

    An NVMe subsystem maintains configuration state and NVMe namespace access control for a set of NVMe-connected hosts.

  `summary: Error GET`

    The summary field of the nvme_subsystem_replication_error.